@@ -1715,6 +1715,8 @@ PrivateCubeScreen::~PrivateCubeScreen ()
 }
 
 
+template class PluginClassHandler<PrivateCubeWindow, CompWindow, COMPIZ_CUBE_ABI>;
+
 PrivateCubeWindow::PrivateCubeWindow (CompWindow *w) :
     PluginClassHandler<PrivateCubeWindow, CompWindow, COMPIZ_CUBE_ABI> (w),
     window (w),
@@ -1729,6 +1731,8 @@ PrivateCubeWindow::~PrivateCubeWindow ()
 {
 }
 
+template class PluginClassHandler<CubeScreen, CompScreen, COMPIZ_CUBE_ABI>;
+
 CubeScreen::CubeScreen (CompScreen *s) :
     PluginClassHandler<CubeScreen, CompScreen, COMPIZ_CUBE_ABI> (s),
     priv (new PrivateCubeScreen (s))
